tlslite.integration.xmlrpctransport.XMLRPCTransport

Package tlslite :: Package integration :: Module xmlrpctransport :: Class XMLRPCTransport |
[hide private]
[frames] | no frames]

# Class XMLRPCTransport

source code

          xmlrpclib.Transport --+
                                |
    clienthelper.ClientHelper --+
                                |
                               XMLRPCTransport

Handles an HTTPS transaction to an XML-RPC server.

Instance Methods | [hide private]
__init__(self, use_datetime=0, username=None, password=None, certChain=None, privateKey=None, checker=None, settings=None, ignoreAbruptClose=False) Create a new XMLRPCTransport. | source code
make_connection(self, host) | source code
Inherited from `xmlrpclib.Transport`: `close`, `get_host_info`, `getparser`, `parse_response`, `request`, `send_content`, `send_host`, `send_request`, `send_user_agent`, `single_request` Inherited from `clienthelper.ClientHelper` (private): `_handshake`

Class Variables | [hide private]
| conn_class_is_http = `False`
Inherited from `xmlrpclib.Transport`: `accept_gzip_encoding`, `encode_threshold`, `user_agent`

Method Details | [hide private]

### __init__(self, use_datetime=0, username=None, password=None, certChain=None, privateKey=None, checker=None, settings=None, ignoreAbruptClose=False) (Constructor) | source code
Create a new XMLRPCTransport. An instance of this class can be passed to `xmlrpclib.ServerProxy` to use TLS with XML-RPC calls:
       from tlslite import XMLRPCTransport
       from xmlrpclib import ServerProxy

       transport = XMLRPCTransport(user="alice", password="abra123")
       server = ServerProxy("https://localhost", transport)
For client authentication, use one of these argument combinations: username, password (SRP) certChain, privateKey (certificate) For server authentication, you can either rely on the implicit mutual authentication performed by SRP or you can do certificate-based server authentication with one of these argument combinations: x509Fingerprint Certificate-based server authentication is compatible with SRP or certificate-based client authentication. The constructor does not perform the TLS handshake itself, but simply stores these arguments for later. The handshake is performed only when this class needs to connect with the server. Thus you should be prepared to handle TLS-specific exceptions when calling methods of `xmlrpclib.ServerProxy`. See the client handshake functions in tlslite.TLSConnection.TLSConnection for details on which exceptions might be raised. Parameters: `username` (str) - SRP username. Requires the 'password' argument. `password` (str) - SRP password for mutual authentication. Requires the 'username' argument. `certChain` (tlslite.x509certchain.X509CertChain) - Certificate chain for client authentication. Requires the 'privateKey' argument. Excludes the SRP arguments. `privateKey` (tlslite.utils.rsakey.RSAKey) - Private key for client authentication. Requires the 'certChain' argument. Excludes the SRP arguments. `checker` (tlslite.checker.Checker) - Callable object called after handshaking to evaluate the connection and raise an Exception if necessary. `settings` (tlslite.handshakesettings.HandshakeSettings) - Various settings which can be used to control the ciphersuites, certificate types, and SSL/TLS versions offered by the client. `ignoreAbruptClose` (bool) - ignore the TLSAbruptCloseError on unexpected hangup. Overrides: clienthelper.ClientHelper.__init__

### make_connection(self, host) | source code
Overrides: xmlrpclib.Transport.make_connection